// Default empty project template
import bb.cascades 1.0

// creates one page with a label
Page {
    id: mainPage
    property bool showOverlay: false
    
    titleBar: TitleBar {
        kind: TitleBarKind.FreeForm
        scrollBehavior: TitleBarScrollBehavior.Sticky
        kindProperties: FreeFormTitleBarKindProperties {
            content: Container {
                layout: DockLayout {
                }
                Container {
                    verticalAlignment: VerticalAlignment.Center
                    leftPadding: 15.0

                    Label {
                        text: "GnGeo"
                        textStyle.fontSize: FontSize.Large
                        textStyle.color: Color.White
                    }
                }
                Container {
                    verticalAlignment: VerticalAlignment.Center

                    horizontalAlignment: HorizontalAlignment.Right
                    rightPadding: 15.0
                    ImageView {
                        imageSource: "asset:///images/icon.png"
                    }
                }
            }
        }
    }
    Container {
        layout: DockLayout {
        }
        Container {
            horizontalAlignment: HorizontalAlignment.Fill
            topPadding: 15.0
            ImageView {
                horizontalAlignment: HorizontalAlignment.Center
                //imageSource: "asset:///images/mslug2.png"
                image: _native.image
                visible: _native.hasImage
                scalingMethod: ScalingMethod.AspectFit
                loadEffect: ImageViewLoadEffect.FadeZoom
                maxWidth: 720.0
                maxHeight: 300.0
                
                onTouch: {
                    if (event.touchType == TouchType.Up) {
	                    var sheet = imageSheet.createObject(_native)
	                    sheet.open()
	                }
                }
            }
            Label {
                horizontalAlignment: HorizontalAlignment.Center
                text: _native.romName
                visible: _native.romSelected
            }
            Button {
                horizontalAlignment: HorizontalAlignment.Center
                text: qsTr("Open ROM")
                imageSource: _native.Bright ? "asset:///images/open.png" : "asset:///images/ic_open.png"

                onClicked: {
                    _native.selectFile()
                }
            }
            Button {
                horizontalAlignment: HorizontalAlignment.Center
                text: _native.recentButtonText
                visible: _native.Keyboard
                
                onClicked: {
                    var sheet = recentSheet.createObject(_native)
                    sheet.open()
                }
            }
        }
        Container {
            verticalAlignment: VerticalAlignment.Bottom
            horizontalAlignment: HorizontalAlignment.Fill
            maxHeight: _native.hasImage ? 450 : 750
            visible: _native.hasRecentFiles && !_native.Keyboard

            Header {
                title: _native.sortHeaderText
            }
            ListView {
                id: recentList
                //dataModel: _native.recentDataModel
                dataModel: listModel.model

                listItemComponents: [
                    ListItemComponent {
                        type: ""

                        /*StandardListItem {
                            title: ListItemData.name
                            description: ListItemData.desc
                        }*/
                        
                        Container {
                            id: containerContents
                            contextActions: [
                                ActionSet {
                                    title: ListItemData.name
                                    DeleteActionItem {
                                        title: qsTr("Delete")

                                        onTriggered: {
                                            var tmpListView = parent.parent.parent
                                            var itemData = tmpListView.dataModel.data(tmpListView.selected())
                                            tmpListView.remove(itemData.index)
                                        }
                                    }
                                }
                            ]

                            layout: StackLayout {
                                orientation: LayoutOrientation.TopToBottom
                            }
	                        Container {
	                            layout: DockLayout {
	                            }
	                            leftPadding: 15
	                            topPadding: 15
	                            rightPadding: 15
	                            bottomPadding: 15
	                            horizontalAlignment: HorizontalAlignment.Fill
	                            Container {
	                                verticalAlignment: VerticalAlignment.Center
	                                Container {
	                                    bottomMargin: 0
	                                    
	                                    Label {
	                                        text: ListItemData.name
	                                        
	                                        textStyle {
	                                            base: SystemDefaults.TextStyles.TitleText
	                                            fontWeight: FontWeight.Normal
	                                        }
	                                    }
	                                }
	                                Container {
	                                    topMargin: 0
	                                    
	                                    Label {
	                                        text: ListItemData.desc
	                                        
	                                        textStyle {
	                                            fontSize: FontSize.Small
	                                        }
	                                    }
	                                }
	                            }
	                            
	                            /*Container {
	                                verticalAlignment: VerticalAlignment.Center
	                                horizontalAlignment: HorizontalAlignment.Right
	                                
	                                ImageButton {
	                                    defaultImageSource: "asset:///images/edit_black.png"
	                                    pressedImageSource: "asset:///images/edit_black.png"
	                                    disabledImageSource: "asset:///images/edit_black.png"

	                                    onClicked: {
                                            var tmpListView = containerContents.ListItem.view
                                            tmpListView.edit(ListItemData.index)
                                        }
	                                }
	                            }*/
	                        }

                            Divider {
                            }
                        }
                    }
                ]

                function edit(index) {
                    _native.recentFileEdit(index)
                }

                function remove(index) {
                    _native.recentFileRemove(index)
                }

                onTriggered: {
                    var selectedItem = dataModel.data(indexPath)
                    _native.recentFileSelected(selectedItem.index)
                }
            }
        }
    }
    
    attachedObjects: [
        ComponentDefinition {
            id: settingsSheet
            source: "settings.qml"
        },
        ComponentDefinition {
            id: editSheet
            source: "edit.qml"
        },
        ComponentDefinition {
            id: biosSheet
            source: "bios.qml"
        },
        ComponentDefinition {
            id: recentSheet
            source: "recent.qml"
        },
        ComponentDefinition {
            id: imageSheet
            source: "image.qml"
        },
        ComponentDefinition {
            id: gameplaySheet
            source: "gameplay.qml"
        },
        ComponentDefinition {
            id: addListAction
            ActionItem {
                title: qsTr("Populate Recent List")
                imageSource: "asset:///images/ic_add_folder.png"
                ActionBar.placement: ActionBarPlacement.InOverflow

                onTriggered: {
                    _native.indexDirectory()
                }
            }
        },
        ComponentDefinition {
            id: sortListAction
            ActionItem {
                title: _native.sortChangeText
                imageSource: "asset:///images/ic_sort.png"
                ActionBar.placement: ActionBarPlacement.InOverflow
                
                onTriggered: {
                    _native.switchSort()
                }
            }
        }
    ]

    actions: [
        ActionItem {
            title: qsTr("Play")
            imageSource: "asset:///images/play.png"
            enabled: _native.romReady
            ActionBar.placement: ActionBarPlacement.OnBar
            
            onTriggered: {
                var sheet = gameplaySheet.createObject(_native)
                sheet.open()
                _native.start()
            }
        },
        ActionItem {
            title: qsTr("Edit ROM")
            imageSource: "asset:///images/ic_edit.png"
            enabled: _native.romSelected
            ActionBar.placement: ActionBarPlacement.InOverflow
            
            onTriggered: {
                _native.editROM()
            }
        }
    ]
    
    function openEditSheet() {
        var sheet = editSheet.createObject(_native)
        sheet.open()
    }
    
    onCreationCompleted: {
        _native.openEditSheet.connect(openEditSheet)
        
        if (_native.firstRun) {
            var sheet = biosSheet.createObject(_native)
            sheet.open()
        }

        if (!_native.Keyboard) {
            var action = addListAction.createObject(_native)
            mainPage.addAction(action, ActionBarPlacement.InOverflow)
            var action2 = sortListAction.createObject(_native)
            mainPage.addAction(action2, ActionBarPlacement.InOverflow)
        }
    }

    Menu.definition: MenuDefinition {
        actions: [
            ActionItem {
                title: qsTr("BIOS")
                imageSource: "asset:///images/bios.png"

                onTriggered: {
                    var sheet = biosSheet.createObject(_native)
                    sheet.open()
                }
            },
            ActionItem {
                title: qsTr("Settings")
                imageSource: "asset:///images/settings.png"
                
                onTriggered: {
                    var sheet = settingsSheet.createObject(_native)
                    sheet.open()
                }
            }
        ]
    }
}

